@@ -6,16 +6,16 @@ import signal
 import subprocess
 import time
 
-from typing import Optional, List, IO, Any, Union, Dict, Tuple
+from typing import Optional, List, IO, Any, Union, Tuple
 
 from . import linux
 from . import utils
-from . import static
 from . import qemu
 
 SSH_CONNECTION_WAIT_TIME = 30
 SSH_CONNECTION_TIME_BETWEEN_TRIES = 2
 SSH_DEFAULT_CONNECT_TIMEOUT = 3
+SSH_DEFAULT_TOTAL_TIMEOUT = 90
 
 
 class SshConfig:
@@ -31,7 +31,7 @@ class SshConfig:
         host: str,
         port: Optional[int] = None,
         ssh_bin_name: Optional[str] = None,
-        sftp_server_bin_name: Optional[str] = None,
+        sftp_bin_name: Optional[str] = None,
         user: Optional[str] = None,
         password: Optional[str] = None,
         args: Optional[List[str]] = None,
@@ -43,7 +43,7 @@ class SshConfig:
         self.password = password
         self.args = args or []
         self.ssh_bin_name = ssh_bin_name or self.__find_ssh_bin_name()
-        self.sftp_server_bin_name = sftp_server_bin_name or "sftp-server"
+        self.sftp_bin_name = sftp_bin_name or "sftp-server"
 
         # Pass these as default args
         self.args.extend(self.__default_ssh_args())
