@@ -68,9 +68,27 @@ class BaseImageProtocol:
 
             self._do_retrieve_image(store, spec, temp_file)
 
-            # Now that the entire file is retrieved, atomically move it to the destination.
-            # This avoids issues where a process was killed in the middle of retrieval
-            os.rename(temp_destination, destination)
+            logging.info("Converting new image to qcow2")
+
+            # Do a convert to ensure that any image we're getting from any protocol
+            # is a qcow2 once we put it in the backend.
+            convert_path = os.path.join(store.working, str(uuid.uuid4()))
+            utils.run_check_retcode(
+                [
+                    store.qemu_img_bin,
+                    "convert",
+                    "-O",
+                    "qcow2",
+                    temp_destination,
+                    convert_path,
+                ]
+            )
+
+            # Now that the entire file is retrieved and converted, atomically move it
+            # to the destination and clean up the intermediate. This avoids issues where
+            # a process was killed in the middle of retrieval
+            os.rename(convert_path, destination)
+            os.remove(temp_destination)
 
             # There is a qemu hotkey to commit a 'snapshot' to the backing file.
             # Making the backend images read-only prevents this.
@@ -409,7 +427,8 @@ class BackendImageStore:
                     self.qemu_img_bin,
                     "convert",
                     primary_image.path,
-                    "-O" "qcow2",
+                    "-O",
+                    "qcow2",
                     "-p",
                     working,
                 ],
@@ -449,7 +468,7 @@ class VmPersistentState:
 
     def __find_primary_image(self, images: List[FrontendImageInfo]) -> FrontendImageInfo:
         for image in self.images:
-            if image.backend_image_name == ImageSpec(self.config.primary_image).name:
+            if image.backend_image_name == ImageSpec(self.config.image).name:
                 return image
         raise utils.TransientError(msg=f"Unable to find primary image for '{self.name}'")
 
@@ -493,7 +512,7 @@ class VmStore:
             logging.debug(f"Using {tempdir} as temporary state directory")
 
             logging.debug(f"Creating VM disk images")
-            images = [self.__create_vm_image(config.primary_image, name, 0, tempdir)]
+            images = [self.__create_vm_image(config.image, name, 0, tempdir)]
             images.extend(
                 [
                     self.__create_vm_image(img, name, i + 1, tempdir)
@@ -564,7 +583,8 @@ class VmStore:
                 "create",
                 "-f",
                 "qcow2",
-                "-F" "qcow2",
+                "-F",
+                "qcow2",
                 "-o",
                 f"backing_file={backing_image.path}",
                 new_image_path,
@@ -629,7 +649,7 @@ class VmStore:
         # This may throw at any point, as we don't hold the lock, so
         # supress errors and return None
         try:
-            config = configuration.load_config_file(cfg_path)
+            config = configuration.load_create_config(cfg_path)
 
             images = []
             for filename in os.listdir(dir):
